@@ -20,8 +20,10 @@ A project name **must** be unique and each manifest must have at least one proje
 
 Revision/Branch/Tag
 ###################
-Since we want more control on what project is retrieved the ``revision:``, ``branch:`` and ``tag:``
-attributes can help. Below manifest will download tag ``v1.13`` of ``mymodule``.
+When no version is provided the latest version of the default branch (e.g. `trunk`, `master`) of
+a project will be chosen. Since we want more control on what project is retrieved the
+``revision:``, ``branch:`` and ``tag:`` attributes can help.
+Below manifest will download tag ``v1.13`` of ``mymodule``.
 
 The ``tag:`` attribute takes priority over ``revision:`` and ``branch:``.
 With ``revision:`` a specific commit (git) or revision (svn) is retrieved. For git,
@@ -43,8 +45,9 @@ revisions must be complete 40 character long SHA-hashes.
          - name: myothermodule
            revision: dcc92d0ab6c4ce022162a23566d44f673251eee4
 
-For svn a `standard layout`_ is assumed. Meaning the top of the repository has a ``trunk``,
-``branches`` and ``tags`` folder.
+.. note:: For svn a `standard layout`_ is advised. Meaning the top of the repository has a ``trunk``,
+          ``branches`` and ``tags`` folder. If this is not the case, you can indicate this by using
+          ``branch: ' '``.
 
 .. _`standard layout`:
     https://stackoverflow.com/questions/3859009/how-to-create-a-subversion-repository-with-standard-layout
@@ -67,6 +70,8 @@ will place ``mymodule`` at the relative path listed by ``dst:`` (relative to the
          - name: mymodule
            dst: external/mymodule
 
+If no ``dst:`` is provided, dfetch will use the project name as relative path.
+
 Repo-path
 #########
 When working with remotes_ by default *Dfetch* will take the ``url-base`` of the remote
@@ -143,6 +148,27 @@ from trunk for svn and master from git.
           vcs: svn
           repo-path: cpputest/cpputest
 
+Patch
+#####
+*DFetch* promotes upstreaming changes, but also allows local changes. These changes can be managed with a local patch
+file. *DFetch* will apply the patch file everytime a new upstream version is fetched. The patch file can be specified
+with the ``patch:`` attribute.
+
+.. code-block:: yaml
+
+    manifest:
+        version: 0.0
+
+        remotes:
+        - name: github
+          url-base: https://github.com/
+
+        projects:
+        - name: cpputest
+          vcs: git
+          repo-path: cpputest/cpputest
+          patch: local_changes.patch
+
 """
 import copy
 from typing import Dict, Optional, Union
@@ -150,6 +176,7 @@ from typing import Dict, Optional, Union
 from typing_extensions import TypedDict
 
 from dfetch.manifest.remote import Remote
+from dfetch.manifest.version import Version
 
 ProjectEntryDict = TypedDict(
     "ProjectEntryDict",
@@ -236,6 +263,23 @@ class ProjectEntry:  # pylint: disable=too-many-instance-attributes
         """Set the parent."""
         self._parent = parent
 
+    @property
+    def version(self) -> Version:
+        """Get the version of the project."""
+        if self._tag:
+            return Version(tag=self._tag)
+
+        return Version(branch=self._branch, revision=self._revision)
+
+    @version.setter
+    def version(self, version: Version) -> None:
+        """Set the version of the project."""
+        if version.tag:
+            self._tag = version.tag
+        else:
+            self._branch = version.branch
+            self._revision = version.revision
+
     @property
     def remote_url(self) -> str:
         """Get the remote url of the project."""
@@ -266,6 +310,11 @@ class ProjectEntry:  # pylint: disable=too-many-instance-attributes
         """Get the local path the project should be copied to."""
         return self._dst
 
+    @property
+    def patch(self) -> str:
+        """Get the patch that should be applied."""
+        return self._patch
+
     @property
     def branch(self) -> str:
         """Get the branch that should be fetched."""
@@ -302,7 +351,7 @@ class ProjectEntry:  # pylint: disable=too-many-instance-attributes
             "revision": self._revision,
             "remote": self._remote,
             "src": self._src,
-            "dst": self._dst,
+            "dst": self._dst if self._dst != self._name else None,
             "url": self._url,
             "patch": self._patch,
             "branch": self._branch,
