@@ -5,11 +5,12 @@ import pathlib
 import re
 import shutil
 from collections import namedtuple
+from pathlib import PurePath
 from typing import Dict, List, Optional, Tuple
 
 from dfetch.log import get_logger
+from dfetch.manifest.version import Version
 from dfetch.project.vcs import VCS
-from dfetch.project.version import Version
 from dfetch.util.cmdline import SubprocessCommandError, run_on_cmdline
 from dfetch.util.util import in_directory, safe_rmtree
 
@@ -193,16 +194,19 @@ class GitRepo(VCS):
             run_on_cmdline(logger, "git config core.sparsecheckout true")
             with open(".git/info/sparse-checkout", "a") as sparse_checkout_file:
                 sparse_checkout_file.write(
-                    "\n".join(["/" + src, "LICENSE*", "COPYING*"])
+                    "\n".join(["/" + src, "/LICENSE*", "/COPYING*"])
                 )
 
         run_on_cmdline(logger, f"git fetch --depth 1 origin {version}")
         run_on_cmdline(logger, "git reset --hard FETCH_HEAD")
 
         if src:
+            if os.path.isfile(src):
+                src = os.path.dirname(src)
+
             for file_to_copy in os.listdir(src):
                 shutil.move(src + "/" + file_to_copy, ".")
-            safe_rmtree(src)
+            safe_rmtree(PurePath(src).parts[0])
 
     @staticmethod
     def _ls_remote(remote: str) -> Dict[str, str]:
