@@ -7,8 +7,8 @@ from collections import namedtuple
 from typing import Dict, List, Tuple
 
 from dfetch.log import get_logger
+from dfetch.manifest.version import Version
 from dfetch.project.vcs import VCS
-from dfetch.project.version import Version
 from dfetch.util.cmdline import SubprocessCommandError, run_on_cmdline
 from dfetch.util.util import in_directory
 
@@ -42,26 +42,33 @@ class SvnRepo(VCS):
         repo_root = SvnRepo._get_info_from_target()["Repository Root"]
 
         externals = []
+        path_pattern = r"([^\s^-]+)\s+-"
         for entry in result.stdout.decode().split(os.linesep * 2):
 
             match = None
-            for match in re.finditer(r"([^\s^-]+)\s+-", entry):
+            for match in re.finditer(path_pattern, entry):
                 pass
             if match:
                 local_path = match.group(1)
+                entry = re.sub(path_pattern, "", entry)
 
-            for match in re.finditer(r"([^\s]+)(?:@)(\d+)\s+([^\s]+)", entry):
+            for match in re.finditer(
+                r"([^-\s\d][^\s]+)(?:@)(\d+)\s+([^\s]+)|([^-\s\d][^\s]+)\s+([^\s]+)",
+                entry,
+            ):
 
-                url, branch, tag, src = SvnRepo._split_url(match.group(1), repo_root)
+                url = match.group(1) or match.group(4)
+                name = match.group(3) or match.group(5)
+                rev = "" if not match.group(2) else match.group(2).strip()
+
+                url, branch, tag, src = SvnRepo._split_url(url, repo_root)
 
                 externals += [
                     External(
-                        name=match.group(3),
+                        name=name,
                         toplevel=os.getcwd(),
-                        path="/".join(
-                            os.path.join(local_path, match.group(3)).split(os.sep)
-                        ),
-                        revision=match.group(2).strip(),
+                        path="/".join(os.path.join(local_path, name).split(os.sep)),
+                        revision=rev,
                         url=url,
                         branch=branch,
                         tag=tag,
@@ -79,7 +86,7 @@ class SvnRepo(VCS):
         # //    Relative to the scheme of the URL of the directory on which the svn:externals property is set
         # /     Relative to the root URL of the server on which the svn:externals property is versioned
         url = re.sub(r"^\^", repo_root, url)
-        branch = ""
+        branch = " "
         tag = ""
         src = ""
 
@@ -158,6 +165,9 @@ class SvnRepo(VCS):
         if version.tag:
             branch_path = f"tags/{version.tag}/"
             branch = ""
+        elif version.branch == " ":
+            branch_path = ""
+            branch = " "
         else:
             branch = version.branch or self.DEFAULT_BRANCH
             branch_path = (
@@ -178,7 +188,9 @@ class SvnRepo(VCS):
         branch, branch_path, revision = self._determine_what_to_fetch(version)
         rev_arg = f"--revision {revision}" if revision else ""
 
-        complete_path = "/".join([self.remote, branch_path, self.source]).strip("/")
+        complete_path = "/".join(
+            filter(None, [self.remote, branch_path.strip(), self.source])
+        ).strip("/")
 
         # When exporting a file, the destination directory must already exist
         pathlib.Path(os.path.dirname(self.local_path)).mkdir(
@@ -230,7 +242,7 @@ class SvnRepo(VCS):
 
     @staticmethod
     def _get_info_from_target(target: str = "") -> Dict[str, str]:
-        result = run_on_cmdline(logger, f"svn info {target}").stdout.decode()
+        result = run_on_cmdline(logger, f"svn info {target.strip()}").stdout.decode()
 
         return {
             key.strip(): value.strip()
