@@ -4,10 +4,12 @@ import os
 from abc import ABC, abstractmethod
 from typing import List, Optional, Tuple
 
+from patch_ng import fromfile
+
 import dfetch.manifest.manifest
 from dfetch.log import get_logger
+from dfetch.manifest.version import Version
 from dfetch.project.metadata import Metadata
-from dfetch.project.version import Version
 from dfetch.util.util import hash_directory, safe_rm
 from dfetch.util.versions import latest_tag_from_list
 
@@ -35,7 +37,7 @@ class VCS(ABC):
         Returns:
             Tuple[Optional[Version], Optional[Version]]: Wanted, Have
         """
-        on_disk = self._on_disk_version()
+        on_disk = self.on_disk_version()
 
         if not on_disk:
             return (self.wanted_version, None)
@@ -101,6 +103,10 @@ class VCS(ABC):
 
         actually_fetched = self._fetch_impl(to_fetch)
         self._log_project(f"Fetched {actually_fetched}")
+
+        if self.__project.patch and os.path.exists(self.__project.patch):
+            self.apply_patch()
+
         self.__metadata.fetched(
             actually_fetched,
             hash_=hash_directory(self.local_path, skiplist=[self.__metadata.FILENAME]),
@@ -109,9 +115,21 @@ class VCS(ABC):
         logger.debug(f"Writing repo metadata to: {self.__metadata.path}")
         self.__metadata.dump()
 
+    def apply_patch(self) -> None:
+        """Apply the specified patch to the destination."""
+        patch_set = fromfile(self.__project.patch)
+
+        if patch_set:
+            if patch_set.apply(0, root=self.__project.destination, fuzz=True):
+                self._log_project(f'Applied path "{self.__project.patch}"')
+            else:
+                raise RuntimeError(f'Applying path "{self.__project.patch}" failed')
+        else:
+            raise RuntimeError(f'Invalid patch file: "{self.__project.patch}"')
+
     def check_for_update(self) -> None:
         """Check if there is an update available."""
-        on_disk_version = self._on_disk_version()
+        on_disk_version = self.on_disk_version()
         latest_version = self._check_for_newer_version()
 
         if not on_disk_version:
@@ -127,7 +145,8 @@ class VCS(ABC):
             )
         else:
             self._log_project(
-                f"wanted ({self.wanted_version}), current ({on_disk_version}), available ({latest_version})"
+                f"wanted ({str(self.wanted_version) or 'latest'}), "
+                f"current ({on_disk_version}), available ({latest_version})"
             )
 
     def _log_project(self, msg: str) -> None:
@@ -179,7 +198,7 @@ class VCS(ABC):
     def list_tool_info() -> None:
         """Print out version information."""
 
-    def _on_disk_version(self) -> Optional[Version]:
+    def on_disk_version(self) -> Optional[Version]:
         """Get the version of the project on disk.
 
         Returns:
@@ -209,8 +228,10 @@ class VCS(ABC):
             return Version(
                 tag=latest_tag_from_list(self.wanted_version.tag, self._list_of_tags())
             )
-
-        branch = self.wanted_version.branch or self.DEFAULT_BRANCH
+        if self.wanted_version.branch == " ":
+            branch = ""
+        else:
+            branch = self.wanted_version.branch or self.DEFAULT_BRANCH
         return Version(revision=self._latest_revision_on_branch(branch), branch=branch)
 
     def _are_there_local_changes(self) -> bool:
